summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThanos Apollo <[email protected]>2024-01-19 15:19:02 +0200
committerThanos Apollo <[email protected]>2024-01-19 15:19:11 +0200
commitf1d032953bae1f5dde9900cbf40364af7327bfa9 (patch)
treee881900d152674cba208d2b5608541f6f9d7b208
parent015a160f2a259cf7c7a723a6135a6f5e839d329e (diff)
Update commentary
-rw-r--r--gnosis.el21
1 files changed, 13 insertions, 8 deletions
diff --git a/gnosis.el b/gnosis.el
index 24a8309..f88dbc5 100644
--- a/gnosis.el
+++ b/gnosis.el
@@ -1,4 +1,4 @@
;;; gnosis.el --- Spaced Repetition System -*- lexical-binding: t; -*-
;; Copyright (C) 2023 Thanos Apollo
@@ -24,9 +24,9 @@
;;; Commentary:
-;; Gnosis (γνῶσις), pronounced "noh-sis", meaning knowledge in Greek, is
-;; a Spaced Repetition System <https://en.wikipedia.org/wiki/Spaced_repetition>
-;; for GNU Emacs.
+;; Gnosis is a spaced repetition system for note taking & self testing,
+;; where notes are taken in a Question/Answer/Explanation-like format
+;; & reviewed in spaced intervals.
;;
;; Gnosis does not implement flashcard type review sessions where the
;; user rates his own answer on an arbitrary scale. Instead implements
@@ -34,9 +34,14 @@
;; the MCQ, multiple choice question, even allow for simulating
;; real-life exams.
;;
-;; Unlike other SRS implementations for GNU Emacs, gnosis not rely on
-;; org-mode. Instead utilizes an sqlite database & git, enabling
-;; efficient data management, manipulation and data integrity.
+;; Gnosis can help you better understand and retain the material by
+;; encouraging active engagement. It also provides a clear structure for
+;; your notes & review sessions, making it easier to study.
+;;
+;; Unlike other SRS implementations for GNU Emacs, gnosis does not
+;; rely on org-mode. Instead utilizes an sqlite database & git,
+;; enabling efficient data management, manipulation and data
+;; integrity.
;;; Code:
@@ -47,7 +52,7 @@
(require 'gnosis-algorithm)
(defgroup gnosis nil
- "Spaced repetition learning tool."
+ "Spaced Repetition System For Note Taking & Self Testing."
:group 'external
:prefix "gnosis-")
@@ -1,4 +1,4 @@
-;;; gnosis.el --- Spaced Repetition System -*- lexical-binding: t; -*-
+;;; gnosis.el --- Spaced Repetition System For Note Taking & Self Testing -*- lexical-binding: t; -*-
;; Copyright (C) 2023 Thanos Apollo